#!/bin/sh 

## /public/scripts/CCBuildUnix.sh
## A Script to perform the required actions on Unix machine for 
## CC build completion
## Two input parameters are required:
##	1. The build name
##	2. The configuration name

if [ $# -lt 2 ]
then
	echo ""
	echo "Usage: $0 build-name configuration-name"
	echo "Example: $0 Build1.8.4 prd_2.0"
	echo ""
	exit 1
fi

RELNAME=$1


if [ $USER != "weblogic" ]
then
	echo ""
	echo "Run this program using login weblogic only. Exit..."
	echo ""
	exit 1
fi


CLASSESDIR=$HOME/classes

if [ -d $CLASSESDIR ]
then
	cd $CLASSESDIR
else
	echo ""
	echo $CLASSESDIR" is not exist. Exit..."
	echo ""
	exit 1
fi


CNFNAME=$2

INSDIR="/public/"$CNFNAME"/ins"
if [ ! -d $INSDIR ]
then
	echo ""
	echo $INSDIR" is not exist. Exit..."
	echo "" 
	exit 1
fi


### How can I know if a host is weblogic server ?


HOSTN=`hostname`
CNFN=`echo $CNFNAME | awk -F. '{print $1}'`
if [ "$CNFN" = "prd_2" ]
then
	if [ "$HOSTN" != "barbaree" ]
	then
		echo ""
		echo "This script can be run for "$CNFNAME" just from Weblogic 4.5.1 servers: barbaree"
		echo "Exit..."
		echo ""
		exit 1
	fi
else 
	if [ $HOSTN != "barbaree" -a $HOSTN != "tavola" ]
	then
		echo ""
		echo "This script can be run for "$CNFNAME" just from Weblogic 5.1 servers: tavola, barbaree"
		echo "Exit..."
		echo ""
		exit 1
	fi
fi


## Copy new classes from temporary location to permanent loaction on weblogic
## server 	
echo "Rename old classes on weblogic server to "$$".globecom"
mv $CLASSESDIR/globecom $CLASSESDIR/$$.globecom
echo "copy new classes to weblogic server"
cp -r $INSDIR/Java/globecom $CLASSESDIR
echo "remove dependency files"
find $CLASSESDIR/globecom -name "*.dependency" -exec rm -f "{}" \;

if [ "$CNFN" != "prd_2" ]
then
	echo "Rename old deploy dir on weblogic server to "$$".deploy"
	mv $CLASSESDIR/deploy $CLASSESDIR/$$.deploy
	cp -r $INSDIR/deploy $CLASSESDIR
fi

## Deploy
echo "deploy......"
echo ""
cd $HOME
pwd

if [ "$CNFN" = "prd_2" ]
then
	/public/scripts/deploy.sh
else
	/public/scripts/deploy51.sh
fi

## packaging the classes
echo "Packaging classes into tar file"
cd $CLASSESDIR
SUNTARFILE="$INSDIR/JavaClasses-SUN-Rel-"$RELNAME".tar"
LNXTARFILE="$INSDIR/JavaClasses-LNX-Rel-"$RELNAME".tar"
INTLTARFILE="$INSDIR/JavaClasses-INTL-Rel-"$RELNAME".tar"
rm -f $SUNTARFILE.gz $LNXTARFILE.gz $INTLTARFILE.gz
tar cvf $SUNTARFILE ./globecom
chmod -R 777 ./globecom
echo "Compressing tar file"
cd $INSDIR
gzip $SUNTARFILE
echo "duplicate gzip file to LNX and INTL"
cp $SUNTARFILE.gz $LNXTARFILE.gz
cp $SUNTARFILE.gz $INTLTARFILE.gz

exit 0
